@@ -1,5 +1,9 @@
 import re
 from django.utils.datastructures import SortedDict as OrderedDict
+try:
+    from django.utils import six
+except ImportError:
+    import six
 
 __all__ = ["ChoiceItem", "DjangoChoices", "C"]
 
@@ -8,7 +12,7 @@ __all__ = ["ChoiceItem", "DjangoChoices", "C"]
 class Labels(dict):
     def __getattribute__(self, name):
         result = dict.get(self, name, None)
-        if result:
+        if result is not None:
             return result
         else:
             raise AttributeError("Label for field %s was not found." % name)
@@ -70,7 +74,7 @@ class DjangoChoicesMeta(type):
         for field_name in fields:
             val = fields[field_name]
             if isinstance(val, ChoiceItem):
-                if val.label:
+                if not val.label is None:
                     label = val.label
                 else:
                     label = cls.name_clean.sub(" ", field_name)
@@ -88,9 +92,8 @@ class DjangoChoicesMeta(type):
 
         return super(DjangoChoicesMeta, cls).__new__(cls, name, bases, attrs)
 
-class DjangoChoices(object):
+class DjangoChoices(six.with_metaclass(DjangoChoicesMeta)):
     order = 0
     choices = ()
     labels = Labels()
     values = {}
-    __metaclass__ = DjangoChoicesMeta
